// 请求响应参数（不包含data）
export interface Result {
  code: string | number
  msg: string
}

// 请求响应参数（包含data）
export interface ResultData<T = any> extends Result {
  data: T
}

// 分页响应参数
export interface ResPage<T> {
  list: T[]
  pageNum: number
  pageSize: number
  total: number
}

// 分页请求参数
export interface PageQuery {
  pageNum: number
  pageSize: number
}

// 分页请求参数
export interface BaseEntity {
  /** 乐观锁 */
  version?: number
  createBy?: any
  createDept?: any
  createTime?: string
  updateBy?: any
  updateTime?: any
}

// 文件上传模块
export namespace Upload {
  export interface ResFileUrl {
    fileUrl: string
  }
}

// 登录模块
export namespace Login {
  export interface ReqLoginForm {
    username: string
    password: string
    rememberMe: boolean
    code: string
    uuid: string
    clientId: string
    grantType: string
    tenantId: string
  }
  export interface ResLogin {
    access_token: string
  }
  export interface ResAuthButtons {
    [key: string]: string[]
  }
}

// 用户管理模块
export namespace User {
  export interface ReqUserParams extends PageQuery {
    username: string
    gender: number
    idCard: string
    email: string
    address: string
    createTime: string[]
    status: string
  }
  export interface ResUserList {
    userId: number
    id: string
    userName: string
    gender: number
    user: { detail: { age: number } }
    idCard: string
    email: string
    address: string
    createTime: string
    status: string
    avatar: string
    photo: any[]
    children?: ResUserList[]
  }
  export interface ResStatus {
    userLabel: string
    userValue: number
  }
  export interface ResGender {
    genderLabel: string
    genderValue: number
  }
  export interface ResDepartment {
    id: string
    name: string
    children?: ResDepartment[]
  }
  export interface ResRole {
    id: string
    name: string
    children?: ResDepartment[]
  }
}
